==> route53recoverycontrolconfig-2.17.166-sources.jar: software/amazon/awssdk/services/route53recoverycontrolconfig/paginators/ListSafetyRulesIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.route53recoverycontrolconfig.paginators;

import java.util.Iterator;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.route53recoverycontrolconfig.Route53RecoveryControlConfigClient;
import software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListSafetyRulesRequest;
import software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListSafetyRulesResponse;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.route53recoverycontrolconfig.Route53RecoveryControlConfigClient#listSafetyRulesPaginator(software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListSafetyRulesRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListSafetyRulesResponse} that can be used
 * to iterate through all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.route53recoverycontrolconfig.paginators.ListSafetyRulesIterable responses = client.listSafetyRulesPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.route53recoverycontrolconfig.paginators.ListSafetyRulesIterable responses = client
 *             .listSafetyRulesPaginator(request);
 *     for (software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListSafetyRulesResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.route53recoverycontrolconfig.paginators.ListSafetyRulesIterable responses = client.listSafetyRulesPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Please notice that the configuration of MaxResults won't limit the number of results you get with the paginator.
 * It only limits the number of results in each page.</b>
 * </p>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #listSafetyRules(software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListSafetyRulesRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class ListSafetyRulesIterable implements SdkIterable<ListSafetyRulesResponse> {
    private final Route53RecoveryControlConfigClient client;

    private final ListSafetyRulesRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public ListSafetyRulesIterable(Route53RecoveryControlConfigClient client, ListSafetyRulesRequest firstRequest) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.nextPageFetcher = new ListSafetyRulesResponseFetcher();
    }

    @Override
    public Iterator<ListSafetyRulesResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    private class ListSafetyRulesResponseFetcher implements SyncPageFetcher<ListSafetyRulesResponse> {
        @Override
        public boolean hasNextPage(ListSafetyRulesResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public ListSafetyRulesResponse nextPage(ListSafetyRulesResponse previousPage) {
            if (previousPage == null) {
                return client.listSafetyRules(firstRequest);
            }
            return client.listSafetyRules(firstRequest.toBuilder().nextToken(previousPage.nextToken()).build());
        }
    }
}

==> route53recoverycontrolconfig-2.20.89-sources.jar: software/amazon/awssdk/services/route53recoverycontrolconfig/paginators/ListSafetyRulesIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.route53recoverycontrolconfig.paginators;

import java.util.Collections;
import java.util.Iterator;
import java.util.function.Function;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedItemsIterable;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.route53recoverycontrolconfig.Route53RecoveryControlConfigClient;
import software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListSafetyRulesRequest;
import software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListSafetyRulesResponse;
import software.amazon.awssdk.services.route53recoverycontrolconfig.model.Rule;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.route53recoverycontrolconfig.Route53RecoveryControlConfigClient#listSafetyRulesPaginator(software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListSafetyRulesRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListSafetyRulesResponse} that can be used
 * to iterate through all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.route53recoverycontrolconfig.paginators.ListSafetyRulesIterable responses = client.listSafetyRulesPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.route53recoverycontrolconfig.paginators.ListSafetyRulesIterable responses = client
 *             .listSafetyRulesPaginator(request);
 *     for (software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListSafetyRulesResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.route53recoverycontrolconfig.paginators.ListSafetyRulesIterable responses = client.listSafetyRulesPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Please notice that the configuration of MaxResults won't limit the number of results you get with the paginator.
 * It only limits the number of results in each page.</b>
 * </p>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #listSafetyRules(software.amazon.awssdk.services.route53recoverycontrolconfig.model.ListSafetyRulesRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class ListSafetyRulesIterable implements SdkIterable<ListSafetyRulesResponse> {
    private final Route53RecoveryControlConfigClient client;

    private final ListSafetyRulesRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public ListSafetyRulesIterable(Route53RecoveryControlConfigClient client, ListSafetyRulesRequest firstRequest) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.nextPageFetcher = new ListSafetyRulesResponseFetcher();
    }

    @Override
    public Iterator<ListSafetyRulesResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    /**
     * Returns an iterable to iterate through the paginated {@link ListSafetyRulesResponse#safetyRules()} member. The
     * returned iterable is used to iterate through the results across all response pages and not a single page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<Rule> safetyRules() {
        Function<ListSafetyRulesResponse, Iterator<Rule>> getIterator = response -> {
            if (response != null && response.safetyRules() != null) {
                return response.safetyRules().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.<ListSafetyRulesResponse, Rule> builder().pagesIterable(this)
                .itemIteratorFunction(getIterator).build();
    }

    private class ListSafetyRulesResponseFetcher implements SyncPageFetcher<ListSafetyRulesResponse> {
        @Override
        public boolean hasNextPage(ListSafetyRulesResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public ListSafetyRulesResponse nextPage(ListSafetyRulesResponse previousPage) {
            if (previousPage == null) {
                return client.listSafetyRules(firstRequest);
            }
            return client.listSafetyRules(firstRequest.toBuilder().nextToken(previousPage.nextToken()).build());
        }
    }
}
